run main microbiome Factor Analyzer algorithm.
Mico_bi_PGMM(
W_count,
G,
Q_g,
pi_g,
mu_g,
sig_g,
V,
m,
B_K,
T_K,
D_K,
cov_str,
iter,
const,
beta_g,
X
)z_ig Estimated latent variable z
cluster Component labels
mu_g Estimated component mean
pi_g Estimated component proportion
B_g Estimated loading matix.
D_g Estimated error covariance
COV Estimated component covariance
beta_g Estimated covariates coefficients.
overall_loglik Complete log likelihood value for each iteration
ICL ICL value
BIC BIC value
AIC AIC value
The microbiome count matrix that you want to analyze.
The number of component
The number of latent dimensions for each component, a vector.
A vector of initial guesses of component proportion
A list of initial guess of mean vector
A list of initial guess of covariance matrix for each component
A list of initial guess of variational varaince
A list of initial guess of variational mean
A list of initial guess of loading matrix.
A list of identity matrix with dimension q.
A list of initial guess of error matrix
The covaraince structure you choose, there are 8 different models belongs to this family:UUU, UUG, UUD, UUC, GUU, GUG, GUD, GUC.
Max iterations, default is 150.
the permutation constant in multinomial distribution. Calculated before the main algorithm in order to save computation time.
initial guess of covariates coefficients.
The regression covariates matrix, which generates by model.matrix.