Main function will perform PLNM factor analyzer and return parameters
Mico_bi_lasso(
W_count,
G,
Q_g,
pi_g,
mu_g,
sig_g,
V,
m,
B_K,
T_K,
D_K,
cov_str,
tuning,
iter,
const,
beta_g,
X
)z_ig Estimated latent variable z
cluster Component labels
mu_g Estimated component mean
pi_g Estimated component proportion
B_g Estimated sparsity loading matrix
D_g Estimated error covariance
COV Estimated component covariance
beta_g Estimated covariates coefficients.
overall_loglik Complete log likelihood value for each iteration
ICL ICL value
BIC BIC value
AIC AIC value
tuning display the tuning parameter you specified.
The microbiome count matrix
All possible number of components. A vector.
A specific number of latent dimension.
A vector of initial guesses of component proportion
A list of initial guess of mean vector
A list of initial guess of covariance matrix for each component
A list of initial guess of variational varaince
A list of initial guess of variational mean
A list of initial guess of loading matrix.
A list of identity matrix with dimension q.
A list of initial guess of error matrix
The covaraince structure you choose, there are 2 different models belongs to this family:UUU and GUU. You can choose more than 1 covarance structure to do model selection.
length G vector with range 0-1, define the tuning parameter for each component
Max iterations, default is 150.
the permutation constant in multinomial distribution. Calculated before the main algorithm in order to save computation time.
initial guess of covariates coefficients.
The regression covariates matrix, which generates by model.matrix.